@@ -1,5 +1,15 @@
 context("Time Update")
 
+test_that("Non-finite date-times are handled correctly", {
+  expect_identical(unclass(time_update(.POSIXct(Inf), hour = 1)), Inf)
+  expect_identical(unclass(time_add(.POSIXct(-Inf), hour = 1)), -Inf)
+  expect_identical(unclass(time_add(.POSIXct(NA_real_), hour = 1)), NA_real_)
+
+  expect_identical(unclass(time_add(.Date(Inf), day = 1)), Inf)
+  expect_identical(unclass(time_add(.Date(-Inf), day = 1)), -Inf)
+  expect_identical(unclass(time_add(.POSIXct(NA_real_), day = 1)), NA_real_)
+})
+
 ## most of the tests are borrowed from lubridate
 
 test_that("update.Date returns a date object", {
@@ -24,21 +34,21 @@ test_that("update.Date returns a posix object if time is manipulated", {
 
 test_that("update.Date performs simple operation as expected", {
   date <- as.Date("05/05/2010", "%m/%d/%Y")
-  expect_that(second(time_update(date, second = 1)), equals(1))
-  expect_that(minute(time_update(date, minute = 1)), equals(1))
-  expect_that(hour(time_update(date, hour = 1)), equals(1))
-  expect_that(mday(time_update(date, mday = 1)), equals(1))
-  expect_that(wday(time_update(date, mday = 1)), equals(6))
-  expect_that(yday(time_update(date, mday = 1)), equals(121))
-  expect_that(yday(time_update(date, yday = 1)), equals(1))
-  expect_that(mday(time_update(date, yday = 1)), equals(1))
-  expect_that(wday(time_update(date, yday = 1)), equals(5))
-  expect_that(wday(time_update(date, wday = 1)), equals(1))
-  expect_that(yday(time_update(date, wday = 1)), equals(123))
-  expect_that(mday(time_update(date, wday = 1)), equals(3))
-  expect_that(month(time_update(date, month = 1)), equals(1))
-  expect_that(year(time_update(date, year = 2000)), equals(2000))
-  expect_match(timechange:::tz(time_update(date, tz = "UTC")), "UTC")
+  expect_equal(second(time_update(date, second = 1)), 1)
+  expect_equal(minute(time_update(date, minute = 1)), 1)
+  expect_equal(hour(time_update(date, hour = 1)), 1)
+  expect_equal(mday(time_update(date, mday = 1)), 1)
+  expect_equal(wday(time_update(date, mday = 1)), 6)
+  expect_equal(yday(time_update(date, mday = 1)), 121)
+  expect_equal(yday(time_update(date, yday = 1)), 1)
+  expect_equal(mday(time_update(date, yday = 1)), 1)
+  expect_equal(wday(time_update(date, yday = 1)), 5)
+  expect_equal(wday(time_update(date, wday = 1)), 1)
+  expect_equal(yday(time_update(date, wday = 1)), 123)
+  expect_equal(mday(time_update(date, wday = 1)), 3)
+  expect_equal(month(time_update(date, month = 1)), 1)
+  expect_equal(year(time_update(date, year = 2000)), 2000)
+  expect_equal(timechange:::tz(time_update(date, tz = "UTC")), "UTC")
 })
 
 test_that("update.POSIXlt returns a POSIXlt object", {
@@ -73,36 +83,36 @@ test_that("update.POSIXct returns a POSIXct object", {
 test_that("update.POSIXt performs simple operation as expected", {
   poslt <- as.POSIXlt("2010-02-03 13:45:59", tz = "GMT", format = "%Y-%m-%d %H:%M:%S")
   posct <- as.POSIXct("2010-02-03 13:45:59", tz = "GMT", format = "%Y-%m-%d %H:%M:%S")
-  expect_that(second(time_update(poslt, second = 1)), equals(1))
-  expect_that(minute(time_update(poslt, minute = 1)), equals(1))
-  expect_that(hour(time_update(poslt, hour = 1)), equals(1))
-  expect_that(mday(time_update(poslt, mday = 1)), equals(1))
-  expect_that(wday(time_update(poslt, mday = 1)), equals(1))
-  expect_that(yday(time_update(poslt, mday = 1)), equals(32))
-  expect_that(yday(time_update(poslt, yday = 1)), equals(1))
-  expect_that(mday(time_update(poslt, yday = 1)), equals(1))
-  expect_that(wday(time_update(poslt, yday = 1)), equals(5))
-  expect_that(wday(time_update(poslt, wday = 1)), equals(1))
-  expect_that(yday(time_update(poslt, wday = 1)), equals(32))
-  expect_that(mday(time_update(poslt, wday = 1)), equals(1))
-  expect_that(month(time_update(poslt, month = 1)), equals(1))
-  expect_that(year(time_update(poslt, year = 2000)), equals(2000))
-  expect_that(second(time_update(posct, second = 1)), equals(1))
-  expect_that(minute(time_update(posct, minute = 1)), equals(1))
-  expect_that(hour(time_update(posct, hour = 1)), equals(1))
-  expect_that(mday(time_update(posct, mday = 1)), equals(1))
-  expect_that(wday(time_update(posct, mday = 1)), equals(1))
-  expect_that(yday(time_update(posct, mday = 1)), equals(32))
-  expect_that(yday(time_update(posct, yday = 1)), equals(1))
-  expect_that(mday(time_update(posct, yday = 1)), equals(1))
-  expect_that(wday(time_update(posct, yday = 1)), equals(5))
-  expect_that(wday(time_update(posct, wday = 1), week_start = 1), equals(1))
-  expect_that(yday(time_update(posct, wday = 1, week_start = 7)), equals(31))
-  expect_that(mday(time_update(posct, wday = 1, week_start = 7)), equals(31))
-  expect_that(month(time_update(posct, month = 1)), equals(1))
-  expect_that(year(time_update(posct, year = 2000)), equals(2000))
-  expect_match(timechange:::tz(time_update(poslt, tz = "UTC")), "UTC")
-  expect_match(timechange:::tz(time_update(posct, tz = "UTC")), "UTC")
+  expect_equal(second(time_update(poslt, second = 1)), 1)
+  expect_equal(minute(time_update(poslt, minute = 1)), 1)
+  expect_equal(hour(time_update(poslt, hour = 1)), 1)
+  expect_equal(mday(time_update(poslt, mday = 1)), 1)
+  expect_equal(wday(time_update(poslt, mday = 1)), 1)
+  expect_equal(yday(time_update(poslt, mday = 1)), 32)
+  expect_equal(yday(time_update(poslt, yday = 1)), 1)
+  expect_equal(mday(time_update(poslt, yday = 1)), 1)
+  expect_equal(wday(time_update(poslt, yday = 1)), 5)
+  expect_equal(wday(time_update(poslt, wday = 1)), 1)
+  expect_equal(yday(time_update(poslt, wday = 1)), 32)
+  expect_equal(mday(time_update(poslt, wday = 1)), 1)
+  expect_equal(month(time_update(poslt, month = 1)), 1)
+  expect_equal(year(time_update(poslt, year = 2000)), 2000)
+  expect_equal(second(time_update(posct, second = 1)), 1)
+  expect_equal(minute(time_update(posct, minute = 1)), 1)
+  expect_equal(hour(time_update(posct, hour = 1)), 1)
+  expect_equal(mday(time_update(posct, mday = 1)), 1)
+  expect_equal(wday(time_update(posct, mday = 1)), 1)
+  expect_equal(yday(time_update(posct, mday = 1)), 32)
+  expect_equal(yday(time_update(posct, yday = 1)), 1)
+  expect_equal(mday(time_update(posct, yday = 1)), 1)
+  expect_equal(wday(time_update(posct, yday = 1)), 5)
+  expect_equal(wday(time_update(posct, wday = 1), week_start = 1), 1)
+  expect_equal(yday(time_update(posct, wday = 1, week_start = 7)), 31)
+  expect_equal(mday(time_update(posct, wday = 1, week_start = 7)), 31)
+  expect_equal(month(time_update(posct, month = 1)), 1)
+  expect_equal(year(time_update(posct, year = 2000)), 2000)
+  expect_equal(timechange:::tz(time_update(poslt, tz = "UTC")), "UTC")
+  expect_equal(timechange:::tz(time_update(posct, tz = "UTC")), "UTC")
 })
 
 test_that("update works with fractional second", {
@@ -163,18 +173,18 @@ test_that("update.POSIXt works on wdays", {
 
 })
 
-test_that("updates on ydas works correctly with leap year", {
-  expect_equal(time_update(ymd("15-02-03", tz = "UTC"), year = 2000, yday = 1),
+test_that("Updates on ydays works correctly with leap year", {
+  expect_equal(time_update(ymd("1915-02-03", tz = "UTC"), year = 2000, yday = 1),
                ymd("2000-01-01", tz = "UTC"))
-  expect_equal(time_update(ymd("15-02-03", tz = "UTC"), year = 2015, yday = 1),
+  expect_equal(time_update(ymd("1915-02-03", tz = "UTC"), year = 2015, yday = 1),
                ymd("2015-01-01", tz = "UTC"))
-  expect_equal(time_update(ymd("15-02-03", tz = "UTC"), year = 2016, yday = 10),
+  expect_equal(time_update(ymd("1915-02-03", tz = "UTC"), year = 2016, yday = 10),
                ymd("2016-01-10", tz = "UTC"))
-  expect_equal(time_update(ymd("15-02-03", tz = "America/New_York"), year = 2000, yday = 1),
+  expect_equal(time_update(ymd("1915-02-03", tz = "America/New_York"), year = 2000, yday = 1),
                ymd("2000-01-01", tz = "America/New_York"))
-  expect_equal(time_update(ymd("15-02-03", tz = "America/New_York"), year = 2015, yday = 1),
+  expect_equal(time_update(ymd("1915-02-03", tz = "America/New_York"), year = 2015, yday = 1),
                ymd("2015-01-01", tz = "America/New_York"))
-  expect_equal(time_update(ymd("15-02-03", tz = "America/New_York"), year = 2016, yday = 10),
+  expect_equal(time_update(ymd("1915-02-03", tz = "America/New_York"), year = 2016, yday = 10),
                ymd("2016-01-10", tz = "America/New_York"))
   expect_equal(time_update(ymd(c("2016-02-29", "2016-03-01")), yday = 1),
                ymd(c("2016-01-01", "2016-01-01")))
@@ -189,91 +199,91 @@ test_that("updates on ydas works correctly with leap year", {
 
 test_that("update performs roll overs correctly for Date objects", {
   date <- as.Date("05/05/2010", "%m/%d/%Y")
-  expect_that(second(time_update(date, second = 61)), equals(1))
-  expect_that(minute(time_update(date, second = 61)), equals(1))
-  expect_that(minute(time_update(date, minute = 61)), equals(1))
-  expect_that(hour(time_update(date, minute = 61)), equals(1))
-  expect_that(hour(time_update(date, hour = 25)), equals(1))
-  expect_that(mday(time_update(date, hour = 25)), equals(6))
-  expect_that(yday(time_update(date, hour = 25)), equals(126))
+  expect_equal(second(time_update(date, second = 61)), 1)
+  expect_equal(minute(time_update(date, second = 61)), 1)
+  expect_equal(minute(time_update(date, minute = 61)), 1)
+  expect_equal(hour(time_update(date, minute = 61)), 1)
+  expect_equal(hour(time_update(date, hour = 25)), 1)
+  expect_equal(mday(time_update(date, hour = 25)), 6)
+  expect_equal(yday(time_update(date, hour = 25)), 126)
   expect_equal(wday(time_update(date, hour = 25)), (wday(date) + 1) %% 7)
-  expect_that(mday(time_update(date, mday = 32)), equals(1))
-  expect_that(month(time_update(date, mday = 32)), equals(6))
-  expect_that(wday(time_update(date, wday = 31)), equals(3))
-  expect_that(month(time_update(date, wday = 31)), equals(6))
-  expect_that(yday(time_update(date, yday = 366)), equals(1))
-  expect_that(month(time_update(date, yday = 366)), equals(1))
-  expect_that(month(time_update(date, month = 13)), equals(1))
-  expect_that(year(time_update(date, month = 13)), equals(2011))
-  expect_match(timechange:::tz(time_update(date, month = 13)), "UTC")
+  expect_equal(mday(time_update(date, mday = 32)), 1)
+  expect_equal(month(time_update(date, mday = 32)), 6)
+  expect_equal(wday(time_update(date, wday = 31)), 3)
+  expect_equal(month(time_update(date, wday = 31)), 6)
+  expect_equal(yday(time_update(date, yday = 366)), 1)
+  expect_equal(month(time_update(date, yday = 366)), 1)
+  expect_equal(month(time_update(date, month = 13)), 1)
+  expect_equal(year(time_update(date, month = 13)), 2011)
+  expect_equal(timechange:::tz(time_update(date, month = 13)), "UTC")
 })
 
 test_that("update performs roll overs correctly for POSIXlt objects", {
   poslt <- as.POSIXlt("2010-05-05 00:00:00", tz = "GMT", format = "%Y-%m-%d %H:%M:%S")
-  expect_that(second(time_update(poslt, second = 61)), equals(1))
-  expect_that(minute(time_update(poslt, second = 61)), equals(1))
-  expect_that(minute(time_update(poslt, minute = 61)), equals(1))
-  expect_that(hour(time_update(poslt, minute = 61)), equals(1))
-  expect_that(hour(time_update(poslt, hour = 25)), equals(1))
-  expect_that(mday(time_update(poslt, hour = 25)), equals(6))
-  expect_that(yday(time_update(poslt, hour = 25)), equals(126))
-  expect_that(wday(time_update(poslt, hour = 25)), equals(4))
-  expect_that(mday(time_update(poslt, mday = 32)), equals(1))
-  expect_that(month(time_update(poslt, mday = 32)), equals(6))
-  expect_that(wday(time_update(poslt, wday = 31)), equals(3))
-  expect_that(month(time_update(poslt, wday = 31)), equals(6))
-  expect_that(yday(time_update(poslt, yday = 366)), equals(1))
-  expect_that(month(time_update(poslt, yday = 366)), equals(1))
-  expect_that(month(time_update(poslt, month = 13)), equals(1))
-  expect_that(year(time_update(poslt, month = 13)), equals(2011))
-  expect_match(timechange:::tz(time_update(poslt, month = 13)), "GMT")
+  expect_equal(second(time_update(poslt, second = 61)), 1)
+  expect_equal(minute(time_update(poslt, second = 61)), 1)
+  expect_equal(minute(time_update(poslt, minute = 61)), 1)
+  expect_equal(hour(time_update(poslt, minute = 61)), 1)
+  expect_equal(hour(time_update(poslt, hour = 25)), 1)
+  expect_equal(mday(time_update(poslt, hour = 25)), 6)
+  expect_equal(yday(time_update(poslt, hour = 25)), 126)
+  expect_equal(wday(time_update(poslt, hour = 25)), 4)
+  expect_equal(mday(time_update(poslt, mday = 32)), 1)
+  expect_equal(month(time_update(poslt, mday = 32)), 6)
+  expect_equal(wday(time_update(poslt, wday = 31)), 3)
+  expect_equal(month(time_update(poslt, wday = 31)), 6)
+  expect_equal(yday(time_update(poslt, yday = 366)), 1)
+  expect_equal(month(time_update(poslt, yday = 366)), 1)
+  expect_equal(month(time_update(poslt, month = 13)), 1)
+  expect_equal(year(time_update(poslt, month = 13)), 2011)
+  expect_equal(timechange:::tz(time_update(poslt, month = 13)), "GMT")
 })
 
 test_that("update performs roll overs correctly for POSIXct objects", {
   posct <- as.POSIXct("2010-05-05 00:00:00", tz = "GMT", format = "%Y-%m-%d %H:%M:%S")
-  expect_that(second(time_update(posct, second = 61)), equals(1))
-  expect_that(minute(time_update(posct, second = 61)), equals(1))
-  expect_that(minute(time_update(posct, minute = 61)), equals(1))
-  expect_that(hour(time_update(posct, minute = 61)), equals(1))
-  expect_that(hour(time_update(posct, hour = 25)), equals(1))
-  expect_that(mday(time_update(posct, hour = 25)), equals(6))
-  expect_that(yday(time_update(posct, hour = 25)), equals(126))
-  expect_that(wday(time_update(posct, hour = 25)), equals(4))
-  expect_that(mday(time_update(posct, mday = 32)), equals(1))
-  expect_that(month(time_update(posct, mday = 32)), equals(6))
-  expect_that(wday(time_update(posct, wday = 31)), equals(3))
-  expect_that(month(time_update(posct, wday = 31)), equals(6))
-  expect_that(yday(time_update(posct, yday = 366)), equals(1))
-  expect_that(month(time_update(posct, yday = 366)), equals(1))
-  expect_that(month(time_update(posct, month = 13)), equals(1))
-  expect_that(year(time_update(posct, month = 13)), equals(2011))
-  expect_match(timechange:::tz(time_update(posct, month = 13)), "GMT")
+  expect_equal(second(time_update(posct, second = 61)), 1)
+  expect_equal(minute(time_update(posct, second = 61)), 1)
+  expect_equal(minute(time_update(posct, minute = 61)), 1)
+  expect_equal(hour(time_update(posct, minute = 61)), 1)
+  expect_equal(hour(time_update(posct, hour = 25)), 1)
+  expect_equal(mday(time_update(posct, hour = 25)), 6)
+  expect_equal(yday(time_update(posct, hour = 25)), 126)
+  expect_equal(wday(time_update(posct, hour = 25)), 4)
+  expect_equal(mday(time_update(posct, mday = 32)), 1)
+  expect_equal(month(time_update(posct, mday = 32)), 6)
+  expect_equal(wday(time_update(posct, wday = 31)), 3)
+  expect_equal(month(time_update(posct, wday = 31)), 6)
+  expect_equal(yday(time_update(posct, yday = 366)), 1)
+  expect_equal(month(time_update(posct, yday = 366)), 1)
+  expect_equal(month(time_update(posct, month = 13)), 1)
+  expect_equal(year(time_update(posct, month = 13)), 2011)
+  expect_equal(timechange:::tz(time_update(posct, month = 13)), "GMT")
 })
 
 test_that("update performs consecutive roll overs correctly for
   Date objects regardless of order", {
     date <- time_update(as.Date("11/01/2010", "%m/%d/%Y"),
                         month = 13, day = 32, hour = 25, minute = 61, second = 61)
-    expect_that(second(date), equals(1))
-    expect_that(minute(date), equals(2))
-    expect_that(hour(date), equals(2))
-    expect_that(mday(date), equals(2))
-    expect_that(wday(date), equals(3))
-    expect_that(yday(date), equals(33))
-    expect_that(month(date), equals(2))
-    expect_that(year(date), equals(2011))
-    expect_match(timechange:::tz(date), "UTC")
+    expect_equal(second(date), 1)
+    expect_equal(minute(date), 2)
+    expect_equal(hour(date), 2)
+    expect_equal(mday(date), 2)
+    expect_equal(wday(date), 3)
+    expect_equal(yday(date), 33)
+    expect_equal(month(date), 2)
+    expect_equal(year(date), 2011)
+    expect_equal(timechange:::tz(date), "UTC")
     date2 <- time_update(as.Date("11/01/2010", "%m/%d/%Y"),
                          second = 61, minute = 61, hour = 25, day = 32, month = 13)
-    expect_that(second(date2), equals(1))
-    expect_that(minute(date2), equals(2))
-    expect_that(hour(date2), equals(2))
-    expect_that(mday(date2), equals(2))
-    expect_that(wday(date2), equals(3))
-    expect_that(yday(date2), equals(33))
-    expect_that(month(date2), equals(2))
-    expect_that(year(date2), equals(2011))
-    expect_match(timechange:::tz(date2), "UTC")
+    expect_equal(second(date2), 1)
+    expect_equal(minute(date2), 2)
+    expect_equal(hour(date2), 2)
+    expect_equal(mday(date2), 2)
+    expect_equal(wday(date2), 3)
+    expect_equal(yday(date2), 33)
+    expect_equal(month(date2), 2)
+    expect_equal(year(date2), 2011)
+    expect_equal(timechange:::tz(date2), "UTC")
   })
 
 test_that("update performs consecutive roll overs correctly for POSIXlt objects", {
@@ -281,26 +291,26 @@ test_that("update performs consecutive roll overs correctly for POSIXlt objects"
                      tz = "GMT", format = "%Y-%m-%d %H:%M:%S")
   poslt <- time_update(posl, month = 13, day = 32, hour = 25,
                        minute = 61, second = 61)
-  expect_that(second(poslt), equals(1))
-  expect_that(minute(poslt), equals(2))
-  expect_that(hour(poslt), equals(2))
-  expect_that(mday(poslt), equals(2))
-  expect_that(wday(poslt), equals(3))
-  expect_that(yday(poslt), equals(33))
-  expect_that(month(poslt), equals(2))
-  expect_that(year(poslt), equals(2011))
-  expect_match(timechange:::tz(poslt), "GMT")
+  expect_equal(second(poslt), 1)
+  expect_equal(minute(poslt), 2)
+  expect_equal(hour(poslt), 2)
+  expect_equal(mday(poslt), 2)
+  expect_equal(wday(poslt), 3)
+  expect_equal(yday(poslt), 33)
+  expect_equal(month(poslt), 2)
+  expect_equal(year(poslt), 2011)
+  expect_equal(timechange:::tz(poslt), "GMT")
   poslt2 <- time_update(posl, second = 61, minute = 61, hour = 25,
                         day = 32, month = 13)
-  expect_that(second(poslt2), equals(1))
-  expect_that(minute(poslt2), equals(2))
-  expect_that(hour(poslt2), equals(2))
-  expect_that(mday(poslt2), equals(2))
-  expect_that(wday(poslt2), equals(3))
-  expect_that(yday(poslt2), equals(33))
-  expect_that(month(poslt2), equals(2))
-  expect_that(year(poslt2), equals(2011))
-  expect_match(timechange:::tz(poslt2), "GMT")
+  expect_equal(second(poslt2), 1)
+  expect_equal(minute(poslt2), 2)
+  expect_equal(hour(poslt2), 2)
+  expect_equal(mday(poslt2), 2)
+  expect_equal(wday(poslt2), 3)
+  expect_equal(yday(poslt2), 33)
+  expect_equal(month(poslt2), 2)
+  expect_equal(year(poslt2), 2011)
+  expect_equal(timechange:::tz(poslt2), "GMT")
 })
 
 test_that("update performs consecutive roll overs correctly for POSIXct objects", {
@@ -308,26 +318,26 @@ test_that("update performs consecutive roll overs correctly for POSIXct objects"
                      tz = "GMT", format = "%Y-%m-%d %H:%M:%S")
   posct <- time_update(posc, month = 13, day = 32, hour = 25,
                        minute = 61, second = 61)
-  expect_that(second(posct), equals(1))
-  expect_that(minute(posct), equals(2))
-  expect_that(hour(posct), equals(2))
-  expect_that(mday(posct), equals(2))
-  expect_that(wday(posct), equals(3))
-  expect_that(yday(posct), equals(33))
-  expect_that(month(posct), equals(2))
-  expect_that(year(posct), equals(2011))
-  expect_match(timechange:::tz(posct), "GMT")
+  expect_equal(second(posct), 1)
+  expect_equal(minute(posct), 2)
+  expect_equal(hour(posct), 2)
+  expect_equal(mday(posct), 2)
+  expect_equal(wday(posct), 3)
+  expect_equal(yday(posct), 33)
+  expect_equal(month(posct), 2)
+  expect_equal(year(posct), 2011)
+  expect_equal(timechange:::tz(posct), "GMT")
   posct2 <- time_update(posc, second = 61, minute = 61, hour = 25,
                         day = 32, month = 13)
-  expect_that(second(posct2), equals(1))
-  expect_that(minute(posct2), equals(2))
-  expect_that(hour(posct2), equals(2))
-  expect_that(mday(posct2), equals(2))
-  expect_that(wday(posct2), equals(3))
-  expect_that(yday(posct2), equals(33))
-  expect_that(month(posct2), equals(2))
-  expect_that(year(posct2), equals(2011))
-  expect_match(timechange:::tz(posct2), "GMT")
+  expect_equal(second(posct2), 1)
+  expect_equal(minute(posct2), 2)
+  expect_equal(hour(posct2), 2)
+  expect_equal(mday(posct2), 2)
+  expect_equal(wday(posct2), 3)
+  expect_equal(yday(posct2), 33)
+  expect_equal(month(posct2), 2)
+  expect_equal(year(posct2), 2011)
+  expect_equal(timechange:::tz(posct2), "GMT")
 })
 
 test_that("update returns NA for date-times in the spring dst gap", {
@@ -410,9 +420,9 @@ test_that("update handles vectors of dates", {
                       tz = "UTC", format = "%Y-%m-%d %H:%M:%S")
   posct <- as.POSIXct(poslt)
   date <- as.Date(poslt)
-  expect_that(second(time_update(poslt, second = 1)), equals(c(1, 1, 1)))
-  expect_that(second(time_update(posct, second = 1)), equals(c(1, 1, 1)))
-  expect_that(day(time_update(date, day = 1)), equals(c(1, 1, 1)))
+  expect_equal(second(time_update(poslt, second = 1)), c(1, 1, 1))
+  expect_equal(second(time_update(posct, second = 1)), c(1, 1, 1))
+  expect_equal(day(time_update(date, day = 1)), c(1, 1, 1))
 })
 
 test_that("update handles vectors of dates and conformable vector of inputs", {
@@ -420,27 +430,27 @@ test_that("update handles vectors of dates and conformable vector of inputs", {
     01:59:59"), tz = "UTC", format = "%Y-%m-%d %H:%M:%S")
   posct <- as.POSIXct(poslt)
   date <- as.Date(poslt)
-  expect_that(second(time_update(poslt, second = c(1, 2, 3))), equals(c(1, 2, 3)))
-  expect_that(second(time_update(posct, second = c(1, 2, 3))), equals(c(1, 2, 3)))
-  expect_that(day(time_update(date, day = c(1, 2, 3))), equals(c(1, 2, 3)))
+  expect_equal(second(time_update(poslt, second = c(1, 2, 3))), c(1, 2, 3))
+  expect_equal(second(time_update(posct, second = c(1, 2, 3))), c(1, 2, 3))
+  expect_equal(day(time_update(date, day = c(1, 2, 3))), c(1, 2, 3))
 })
 
 test_that("update handles single vector of inputs", {
   poslt <- as.POSIXlt("2010-03-14 01:59:59", tz = "UTC", format = "%Y-%m-%d %H:%M:%S")
   posct <- as.POSIXct(poslt)
   date <- as.Date(poslt)
-  expect_that(second(time_update(poslt, second = c(1, 2, 3))), equals(c(1, 2, 3)))
-  expect_that(second(time_update(posct, second = c(1, 2, 3))), equals(c(1, 2, 3)))
-  expect_that(day(time_update(date, day = c(1, 2, 3))), equals(c(1, 2, 3)))
+  expect_equal(second(time_update(poslt, second = c(1, 2, 3))), c(1, 2, 3))
+  expect_equal(second(time_update(posct, second = c(1, 2, 3))), c(1, 2, 3))
+  expect_equal(day(time_update(date, day = c(1, 2, 3))), c(1, 2, 3))
 })
 
 test_that("update handles conformable vectors of inputs", {
   poslt <- as.POSIXlt("2010-03-10 01:59:59", tz = "UTC", format = "%Y-%m-%d %H:%M:%S")
   posct <- as.POSIXct(poslt)
   date <- as.Date(poslt)
-  expect_that(second(time_update(poslt, second = c(1, 2), minute = c(1, 2, 3, 4))), equals(c(1, 2, 1, 2)))
-  expect_that(second(time_update(posct, second = c(1, 2), minute = c(1, 2, 3, 4))), equals(c(1, 2, 1, 2)))
-  expect_that(day(time_update(date, day = c(1, 2), month = c(1, 2, 3, 4))), equals(c(1, 2, 1, 2)))
+  expect_equal(second(time_update(poslt, second = c(1, 2), minute = c(1, 2, 3, 4))), c(1, 2, 1, 2))
+  expect_equal(second(time_update(posct, second = c(1, 2), minute = c(1, 2, 3, 4))), c(1, 2, 1, 2))
+  expect_equal(day(time_update(date, day = c(1, 2), month = c(1, 2, 3, 4))), c(1, 2, 1, 2))
 })
 
 test_that("update.POSIXct returns input of length zero when given input of length zero", {
